#R script for analyzing Aphonopelma PCA morphospace
#by Chris Hamilton, 2014

#In order to compare your morphological data with that used in the revision, you will need to take our measurements dataset and add your data
#You will need to change filenames and certain other numbers (see notes below)

require(ggplot2)
#Read your CSV datafile into R
data1<-read.csv("pca_male_all.csv",header=T)
#Run PCA analysis - you need to change the number of columns of data you want to perform the pca
pca1<-prcomp(data1[,2:30])
#This will print your PC scores to an output file
capture.output(summary(pca1), file="PC_scores.txt")
#
#Change the data into a dataframe
scores1=as.data.frame(pca1$x)
#Write the dataframe to a file
write.csv(scores1, file="males_all_scores.csv")
#
#Take column 1 from 'data' file and put that column into the 'scores' file (so that the species names are there instead of numbers)
scores1$species <- data1$species
#Resave that file
write.csv(scores1, file="males_all_scores.csv")
#
#Read that renamed file of PCA scores into R
pca1 <- read.csv("males_all_scores.csv")
#
#Plot the PC1~PC2 data and save as PDF
a <- ggplot(data = pca1, aes(x = PC1, y = PC2, col = species, shape = species))
a <- a + geom_point(size = 4, position = "jitter")
#Gives each group a discrete color
a <- a + scale_colour_discrete()
#The numbers in (#,...) correspond to how many different entities, or species, you are plotting and gives them a discrete shape/symbol
a <- a + scale_shape_manual(values=c(1,2,15,3,20,4,5,19,6,7,24,8,9,16,17,18,22,1,2,15,3,20,4,5,19,6,7,24,8,9,16,17,18,22))
a
ggsave(file="males_all_PC1~PC2.pdf", width=10, height=10)
#
#Plot the PC2~PC3 data and save as PDF
b <- ggplot(data = pca1, aes(x = PC2, y = PC3, col = species, shape = species))
b <- b + geom_point(size = 4, position = "jitter")
b <- b + scale_colour_discrete()
b <- b + scale_shape_manual(values=c(1,2,15,3,20,4,5,19,6,7,24,8,9,16,17,18,22,1,2,15,3,20,4,5,19,6,7,24,8,9,16,17,18,22))
b
ggsave(file="males_all_PC2~PC3.pdf", width=10, height=10)
#
#
#
##Plot the first three PCs in 3D (Aphonopelma morphospace in 3D) to screen
##This only prints to the screen. You can rotate this with your mouse by clicking, holding, and moving
##You can also zoom in and out using the wheel on your mouse or using your trackpad
##The legend is printed to the screen, or you can add the commented out command (below)...but I can't get the screen output to save to a file AND I can't get the species names to resize to a smaller size.
library(rgl)
library(pca3d)
data <- read.csv("pca_male_all.csv",header=T)
pca2 <- prcomp(data[,-1], scale.=TRUE)
#pca3d (pca2, group = data[,1], components = 1:3, title = NULL, new = FALSE, axes.color = "grey", bg = "white", show.group.labels=TRUE)
#
##Plot the first three PCs in 3D (Aphonopelma morphospace in 3D) & save as GIF
##This only prints to the screen. You can rotate this with your mouse by clicking, holding, and moving
##You can also zoom in and out using the wheel on your mouse or using your trackpad
##The legend is printed to the screen, or you can add the commented out command (below)...but I can't get the screen output to save to a file AND I can't get the species names to resize to a smaller size.
##plot without species names, rotate, and save as GIF
pca3d(pca2,group=data[,1])
##rotate 3D space
rot<-spin3d(axis=c(0,1,0))
##set PATH where 'convert' package is...if it is not in your PATH already
Sys.setenv(PATH=paste("/sw/bin", Sys.getenv("PATH"), sep=":"))
##animates the rotating 3D space
movie3d(rot,duration= 12)
##[The output gets saved in a temporary directory and the PATH will be printed to the R console]
##[I cannot figure out another way to save it somewhere else; you'll need to copy or move the file - I did it by using 'cp' in shell]
##[You can change the angle of the axes, zoom in or out, and make the window bigger for a larger output, then rerun the script again if you'd like to fine-tune the way the GIF looks]
###Writing movie120.png [this is just output to the screen]
###Will create:  /PATH/movie.gif [it will place the whole path here]
###Executing:  convert -delay 1x10 movie*.png movie.gif 
###Deleting frames

##you can then move that file via shell commands (below)
##cp /PATH/movie.gif ~/Desktop [sudo cp /var/folders/gv/cffkqsmj49v387cyv9dx2x8m0000gq/T//RtmpO4fyGc/movie.gif ~/Desktop/Aphonopelma/morphometrics/pca/males/Sky_Islands/sky_islands3D.gif]
#system("cp /var/folders/gv/cffkqsmj49v387cyv9dx2x8m0000gq/T/RtmpO4fyGc/movie.gif ~/Desktop/Aphonopelma/morphometrics/pca/males/Sky_Islands/sky_islands-3_3D.gif")

##If you don't like the grey background of the 2D plots, you can get rid of it like this...
#a <- ggplot(data = pca1, aes(x = PC1, y = PC2, col = species, shape = species))
##This command (below) is what gives it the white background
#a <- a + theme_minimal()
#a <- a + geom_point(size = 4, position = "jitter")
##Gives each group a discrete color
#a <- a + scale_colour_discrete()
##The numbers in (#,...) correspond to how many different entities, or species, you are plotting and gives them a discrete shape/symbol
#a <- a + scale_shape_manual(values=c(1,2,3,4,5,6,7,8,9,15,16,17,18,19,20,22,24,1,2,3,4,5,6,7,8,9,15,16,17,18))
#a
#ggsave(file="name_file_PC1~PC2.pdf", width=10, height=10)